#pragma once

namespace GLOBAL
{
	// 全局路径;
	extern TCHAR g_szModulePath[MAX_PATH];			// 软件目录;
	extern TCHAR g_szModuleFileName[MAX_PATH];		// 软件名称;

	void Init();
	BOOL StartProcess(LPCTSTR lpApplicationName, LPCTSTR lpCommandLine, CString &strStdOutput);
	CString ReadFileContent(LPCTSTR lpFileName);
	void GetStringList(CString strData, CString strSplit, CStringList &ListStr);
	BOOL FindString(CStringList &ListStr, CString strFind, CString &strResult);
	INT CheckListData(CStringList &listStr);
	BOOL SaveList(CStringList &ListStr);

	BOOL GetFilePath(OUT TCHAR *FilePath, IN HWND hParentWnd, IN TCHAR* InstructionString, IN UINT ulFlags);
};
